# UCI Machine Learning Repository - API
This package provides easy access to a number of datasets from
the UCI Machine Learning repository.

More documentation will come.

## Citation
Make sure you visit UCI and the specific datasets you use to
make sure that they are cited properly.